// Author: Vladimir Savic
// E-mail: vladimirsvc@yahoo.com
// Description: rotate stepper motor in left direction by one step

#include "LeftRotationState.h"
static StateAbstract* ptr;
extern STEPPER_MOTOR_DATA_TYPE StepperMotor;

// **********************************************
// * Left Rotation State: initialization method *
// **********************************************
void LeftRotationStateInitialization (void* ptrSa){
     ptr = (StateAbstract*)ptrSa;

     ptr->Flags = 0xC0; // 1100 0000 binary

     ptr->DefaultStateMethod = &LeftRotationStateMethod;
}

// ***************************************
// * Left Rotation State: default method *
// ***************************************
static void LeftRotationStateMethod( void* command ){

     // *******************************************************************************************************
     // * Stepper motor control signal generation                                                             *
     // * 4 x transistors (Q1, Q2, Q3, Q4) are used to drive stepper motor                                    *
     // * only one transistor is active per generated signal:                                                 *
     // * Time 1, Timer 2, Time 3, Time 4, Time 5, ...                                                        *
     // *  Q1      Q2       Q3      Q4      Q1     ...       RIGHT DIRECTION (handled by right rotation state *
     // *  Q4      Q3       Q2      Q1      Q4     ...       LEFT  DIRECTION                                  *
     // * signal width is determined by timer0 value         (handled by timer state)                         *
     // * to shift signals in time use bitwise shift c operator                                               *
     // * STEPPER_MOTOR.ControlSignals register store current stepper motor position                          *
     // *******************************************************************************************************

     if(StepperMotor.ControlSignals == 0x00 || StepperMotor.ControlSignals == 0x08)
         // reset stepper motor control signals to initial state
         StepperMotor.ControlSignals = 0x01;
     else
         // shift signals in time
         StepperMotor.ControlSignals <<= 1;
         
     StepperMotor.AngleCounter--;
}

// *********************************************
// * Left Rotation State: event handler method *
// *********************************************
static void LeftRotationStateInterruptHandler( void* interruptId ){

}