// Author: Vladimir Savic
// E-mail: vladimirsvc@yahoo.com
// Description: rotate stepper motor in right direction by one step

#include "RightRotationState.h"
static StateAbstract* ptr;
extern STEPPER_MOTOR_DATA_TYPE StepperMotor;

// ***********************************************
// * Right Rotation State: initialization method *
// ***********************************************
void RightRotationStateInitialization (void* ptrSa){
     ptr = (StateAbstract*)ptrSa;
     
     ptr->Flags = 0xC0; // 1100 0000 binary

     ptr->DefaultStateMethod = &RightRotationStateMethod;
}

// ****************************************
// * Right Rotation State: default method *
// ****************************************
static void RightRotationStateMethod( void* command ){

     // *******************************************************************************************************
     // * Stepper motor control signal generation                                                             *
     // * 4 x transistors (Q1, Q2, Q3, Q4) are used to drive stepper motor                                    *
     // * only one transistor is active per generated signal:                                                 *
     // * Time 1, Timer 2, Time 3, Time 4, Time 5, ...                                                        *
     // *  Q1      Q2       Q3      Q4      Q1     ...       RIGHT DIRECTION                                  *
     // *  Q4      Q3       Q2      Q1      Q4     ...       LEFT  DIRECTION (handled by left rotation state) *
     // * signal width is determined by timer0 value         (handled by timer state)                         *
     // * to shift signals in time use bitwise shift c operator                                               *
     // * STEPPER_MOTOR.ControlSignals register store current stepper motor position                          *
     // *******************************************************************************************************

     if(StepperMotor.ControlSignals == 0x00 || StepperMotor.ControlSignals == 0x01)
         // reset stepper motor control signals to initial state
         StepperMotor.ControlSignals = 0x08;
     else
         // shift signals in time
         StepperMotor.ControlSignals >>= 1;
         
     StepperMotor.AngleCounter++;
}

// **********************************************
// * Right Rotation State: event handler method *
// **********************************************
static void RightRotationStateInterruptHandler( void* interruptId ){
}